@@ -1,8 +1,10 @@
 package Email::Sender::Failure;
 {
-  $Email::Sender::Failure::VERSION = '0.120002';
+  $Email::Sender::Failure::VERSION = '1.300002';
 }
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(ArrayRef);
+use Carp ();
 extends 'Throwable::Error';
 # ABSTRACT: a report of failure from an email sending transport
 
@@ -13,14 +15,16 @@ has code => (
 
 
 has recipients => (
-  isa     => 'ArrayRef',
-  traits  => [ 'Array' ],
-  handles => { __recipients => 'elements' },
+  isa     => ArrayRef,
   default => sub {  []  },
   writer  => '_set_recipients',
   reader  => '__get_recipients',
+  is      => 'rw',
+  accessor => undef,
 );
 
+sub __recipients { @{$_[0]->__get_recipients} }
+
 sub recipients {
   my ($self) = @_;
   return $self->__recipients if wantarray;
@@ -33,16 +37,16 @@ sub recipients {
 
 sub BUILD {
   my ($self) = @_;
-  confess("message must contain non-space characters")
+  Carp::confess("message must contain non-space characters")
     unless $self->message =~ /\S/;
 }
 
 
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -51,7 +55,7 @@ Email::Sender::Failure - a report of failure from an email sending transport
 
 =head1 VERSION
 
-version 0.120002
+version 1.300002
 
 =head1 ATTRIBUTES
 
@@ -99,10 +103,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
