@@ -1,20 +1,22 @@
 package Email::Sender::Failure::Multi;
 {
-  $Email::Sender::Failure::Multi::VERSION = '0.120002';
+  $Email::Sender::Failure::Multi::VERSION = '1.300002';
 }
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(ArrayRef);
 extends 'Email::Sender::Failure';
 # ABSTRACT: an aggregate of multiple failures
 
 
 has failures => (
-  isa => 'ArrayRef',
-  traits  => [ 'Array' ],
-  handles  => { __failures => 'elements' },
+  is       => 'ro',
+  isa      => ArrayRef,
   required => 1,
   reader   => '__get_failures',
 );
 
+sub __failures { @{$_[0]->__get_failures} }
+
 sub failures {
   my ($self) = @_;
   return $self->__failures if wantarray;
@@ -51,11 +53,11 @@ sub isa {
   return $self->SUPER::isa($class);
 }
 
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -64,7 +66,7 @@ Email::Sender::Failure::Multi - an aggregate of multiple failures
 
 =head1 VERSION
 
-version 0.120002
+version 1.300002
 
 =head1 DESCRIPTION
 
@@ -91,10 +93,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
