@@ -1,8 +1,8 @@
 package Email::Sender::Role::HasMessage;
 {
-  $Email::Sender::Role::HasMessage::VERSION = '0.120002';
+  $Email::Sender::Role::HasMessage::VERSION = '1.300002';
 }
-use Moose::Role;
+use Moo::Role;
 # ABSTRACT: an object that has a message
 
 
@@ -11,10 +11,11 @@ has message => (
   required => 1,
 );
 
-no Moose::Role;
+no Moo::Role;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -23,7 +24,7 @@ Email::Sender::Role::HasMessage - an object that has a message
 
 =head1 VERSION
 
-version 0.120002
+version 1.300002
 
 =head1 ATTRIBUTES
 
@@ -37,10 +38,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
