@@ -1,8 +1,9 @@
 package Email::Sender::Transport::Sendmail;
 {
-  $Email::Sender::Transport::Sendmail::VERSION = '0.120002';
+  $Email::Sender::Transport::Sendmail::VERSION = '1.300002';
 }
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(Str);
 with 'Email::Sender::Transport';
 # ABSTRACT: send mail via sendmail(1)
 
@@ -11,7 +12,7 @@ use File::Spec ();
 
 has 'sendmail' => (
   is  => 'ro',
-  isa => 'Str',
+  isa => Str,
   required => 1,
   lazy     => 1,
   default  => sub {
@@ -82,11 +83,11 @@ sub send_email {
   return $self->success;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -95,7 +96,7 @@ Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
 =head1 VERSION
 
-version 0.120002
+version 1.300002
 
 =head2 DESCRIPTION
 
@@ -114,10 +115,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
